==> haskell-sockaddr-0.0.1-149.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-sockaddr.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 sockaddr
version:              0.0.1
visibility:           public
id:                   sockaddr-0.0.1-CxFxWRInLW8DoEOnwlAeyL
key:                  sockaddr-0.0.1-CxFxWRInLW8DoEOnwlAeyL
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             Printing SockAddr
description:          Printing SockAddr
category:             Network
abi:                  7f796b5c20d95c2800b681cf46daaab9
exposed:              True
exposed-modules:      Network.SockAddr
import-dirs:          /usr/lib/ghc-9.6.6/site-local/sockaddr-0.0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/sockaddr-0.0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/sockaddr-0.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-sockaddr
hs-libraries:         HSsockaddr-0.0.1-CxFxWRInLW8DoEOnwlAeyL
depends:
    base-4.18.2.1 byteorder-1.0.4-IFlP2E44NdRWUzguGw0c2
    bytestring-0.11.5.3 network-3.1.4.0-8n0F06kM1hW6KWRJNaBKOe

haddock-interfaces:   /usr/share/doc/haskell-sockaddr/html/sockaddr.haddock
haddock-html:         /usr/share/doc/haskell-sockaddr/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-sockaddr-0.0.1-150-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-sockaddr.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 sockaddr
version:              0.0.1
visibility:           public
id:                   sockaddr-0.0.1-Ghn0nteUt1o230LvZgjFZi
key:                  sockaddr-0.0.1-Ghn0nteUt1o230LvZgjFZi
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             Printing SockAddr
description:          Printing SockAddr
category:             Network
abi:                  8d8007f34b6c32673bb30dbaac8dd235
exposed:              True
exposed-modules:      Network.SockAddr
import-dirs:          /usr/lib/ghc-9.6.6/site-local/sockaddr-0.0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/sockaddr-0.0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/sockaddr-0.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-sockaddr
hs-libraries:         HSsockaddr-0.0.1-Ghn0nteUt1o230LvZgjFZi
depends:
    base-4.18.2.1 byteorder-1.0.4-IFlP2E44NdRWUzguGw0c2
    bytestring-0.11.5.3 network-3.1.4.0-JRitsFhJ8rKGUNW13KrLgQ

haddock-interfaces:   /usr/share/doc/haskell-sockaddr/html/sockaddr.haddock
haddock-html:         /usr/share/doc/haskell-sockaddr/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
